/*
 * A dumb photo plugin.
 *
 * Copyright (C) 2009 W. Michael Petullo <mike@flyn.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include <libdmapsharing/dmap.h>
#include <dmapd/dmapd.h>

G_BEGIN_DECLS

#define TYPE_PHOTO_META_READER_DUMMY          (photo_meta_reader_dummy_get_type ())
#define PHOTO_META_READER_DUMMY(o)            (G_TYPE_CHECK_INSTANCE_CAST ((o), \
                                      TYPE_PHOTO_META_READER_DUMMY, PhotoMetaReaderDummy))
#define PHOTO_META_READER_DUMMY_CLASS(k)      (G_TYPE_CHECK_CLASS_CAST ((k), \
                                      TYPE_PHOTO_META_READER_DUMMY, PhotoMetaReaderDummyClass))
#define IS_PHOTO_META_READER_DUMMY(o)         (G_TYPE_CHECK_INSTANCE_TYPE ((o), \
                                      TYPE_PHOTO_META_READER_DUMMY))
#define IS_PHOTO_META_READER_DUMMY_CLASS(k)   (G_TYPE_CHECK_CLASS_TYPE ((k), \
                                      TYPE_PHOTO_META_READER_DUMMY_CLASS))
#define PHOTO_META_READER_DUMMY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), \
                                      TYPE_PHOTO_META_READER_DUMMY, PhotoMetaReaderDummyClass))
#define PHOTO_META_READER_DUMMY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), \
                                      TYPE_PHOTO_META_READER_DUMMY, PhotoMetaReaderDummyPrivate))

typedef struct PhotoMetaReaderDummyPrivate PhotoMetaReaderDummyPrivate;

typedef struct {
        PhotoMetaReader parent;
	PhotoMetaReaderDummyPrivate *priv;
} PhotoMetaReaderDummy;

typedef struct {
        PhotoMetaReaderClass parent;
} PhotoMetaReaderDummyClass;

GType       photo_meta_reader_dummy_get_type      (void);

G_END_DECLS

struct PhotoMetaReaderDummyPrivate {
};

static void
photo_meta_reader_dummy_set_property (GObject *object,
				 guint prop_id,
				 const GValue *value,
				 GParamSpec *pspec)
{
	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
}

static void
photo_meta_reader_dummy_get_property (GObject *object,
				 guint prop_id,
				 GValue *value,
				 GParamSpec *pspec)
{
	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
}

static GOptionGroup *
photo_meta_reader_dummy_get_option_group (PhotoMetaReader *reader)
{
        return NULL;
}

static gboolean
photo_meta_reader_dummy_read (PhotoMetaReader *reader,
			      DPAPRecord *record,
			      const gchar *path)
{
	gint filesize;
	GError *error = NULL;
	gchar *location, *thumbnail;

	location = g_strdup_printf ("file//%s", path);

	g_file_get_contents (path, &thumbnail, &filesize, &error);
	if (error != NULL) {
		g_error ("Error reading %s: %s", path, error->message);
	} else {
		g_object_set (record, "large-filesize", filesize,
				      "filesize", filesize,
				      "thumbnail", thumbnail,
				      NULL);
	}

	g_object_set (record, "creation-date", 1,
			      "rating", 1,
			      "filename", g_basename (path),
			      "location", location,
			      "format", "jpeg",
			      "pixel-height", 640,
			      "pixel-width", 480,
			      "comments", "",
			      "aspect-ratio", 1.33,
			      NULL);

	g_free (thumbnail);
	g_free (location);
}

static void
photo_meta_reader_dummy_class_finalize (PhotoMetaReaderDummyClass *klass)
{
}

static void photo_meta_reader_dummy_register_type (GTypeModule *module);

G_MODULE_EXPORT gboolean
dmapd_module_load (GTypeModule *module)
{
        photo_meta_reader_dummy_register_type (module);
}

G_MODULE_EXPORT gboolean
dmapd_module_unload (GTypeModule *module)
{
}


static void photo_meta_reader_dummy_init (PhotoMetaReaderDummy *reader)
{
	// FIXME: reader->priv = PHOTO_META_READER_DUMMY_GET_PRIVATE (reader);
}

static void photo_meta_reader_dummy_class_init (PhotoMetaReaderDummyClass *klass)
{
	GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
	PhotoMetaReaderClass *photo_meta_reader_class = PHOTO_META_READER_CLASS (klass);

	// FIXME: g_type_class_add_private (klass, sizeof (PhotoMetaReaderDummyPrivate));

	gobject_class->set_property = photo_meta_reader_dummy_set_property;
	gobject_class->get_property = photo_meta_reader_dummy_get_property;

	photo_meta_reader_class->read = photo_meta_reader_dummy_read;
	photo_meta_reader_class->get_option_group = photo_meta_reader_dummy_get_option_group;
}

G_DEFINE_DYNAMIC_TYPE (PhotoMetaReaderDummy,
                       photo_meta_reader_dummy,
		       TYPE_PHOTO_META_READER)
